@@ -9,13 +9,13 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light::Util;
 {
-    $Riak::Light::Util::VERSION = '0.057';
+    $Riak::Light::Util::VERSION = '0.058';
 }
 ## use critic
 use Config;
 use Exporter 'import';
 
-@EXPORT_OK = qw(is_windows is_netbsd_6_32bits);
+@EXPORT_OK = qw(is_windows is_netbsd_6_32bits is_solaris);
 
 sub is_windows {
     $Config{osname} eq 'MSWin32';
@@ -29,6 +29,10 @@ sub _is_netbsd {
     $Config{osname} eq 'netbsd';
 }
 
+sub is_solaris {
+    $Config{osname} eq 'solaris';
+}
+
 1;
 
 
@@ -42,16 +46,26 @@ Riak::Light::Util
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 DESCRIPTION
 
   Internal class
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Tiago Peczenyj <tiago.peczenyj@gmail.com>
 
+=item *
+
+Damien Krotkine <dams@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Weborama.
